@@ -50,7 +50,7 @@ class RsyncEngine(engine.BackupEngine):
     def __init__(
             self, compression, symlinks, exclude, storage,
             max_segment_size, encrypt_key=None,
-            dry_run=False):
+            dry_run=False, **kwargs):
         self.compression_algo = compression
         self.encrypt_pass_file = encrypt_key
         self.dereference_symlink = symlinks
@@ -68,7 +68,7 @@ class RsyncEngine(engine.BackupEngine):
     def name(self):
         return "rsync"
 
-    def metadata(self):
+    def metadata(self, *args):
         return {
             "engine_name": self.name,
             "compression": self.compression_algo,
@@ -77,17 +77,16 @@ class RsyncEngine(engine.BackupEngine):
             "encryption": bool(self.encrypt_pass_file)
         }
 
-    def backup_data(self, backup_path, manifest_path):
+    def backup_data(self, backup_resource, manifest_path):
         """Execute backup using rsync algorithm.
 
         If an existing rsync meta data is available the backup
         will be incremental, otherwise will be executed a level 0 backup
 
-        :param backup_path:
+        :param backup_resource:
         :param manifest_path:
         :return:
         """
-
         LOG.info("Starting RSYNC engine backup data stream")
 
         file_read_limit = 0
@@ -107,7 +106,7 @@ class RsyncEngine(engine.BackupEngine):
         t_get_sign_delta = threading.Thread(
             target=self.get_sign_delta,
             args=(
-                backup_path, manifest_path, rsync_queue))
+                backup_resource, manifest_path, rsync_queue))
         t_get_sign_delta.daemon = True
 
         t_get_sign_delta.start()
@@ -134,7 +133,7 @@ class RsyncEngine(engine.BackupEngine):
         # Rejoining thread
         t_get_sign_delta.join()
 
-    def restore_level(self, restore_path, read_pipe, backup, except_queue):
+    def restore_level(self, restore_resource, read_pipe, backup, except_queue):
         """Restore the provided file into restore_abs_path.
 
         Decrypt the file if backup_opt_dict.encrypt_pass_file key is provided.
@@ -144,7 +143,7 @@ class RsyncEngine(engine.BackupEngine):
             os_stat.st_uid, os_stat.st_gid, os_stat.st_size,
             mtime, ctime, uname, gname, file_type, linkname
 
-        :param restore_path:
+        :param restore_resource:
         :param read_pipe:
         :param backup:
         :param except_queue:
@@ -159,13 +158,13 @@ class RsyncEngine(engine.BackupEngine):
             self.compression_algo = metadata.get('compression',
                                                  self.compression_algo)
 
-            if not os.path.exists(restore_path):
+            if not os.path.exists(restore_resource):
                 raise ValueError(
                     'Provided restore path does not exist: {0}'.format(
-                        restore_path))
+                        restore_resource))
 
             if self.dry_run:
-                restore_path = '/dev/null'
+                restore_resource = '/dev/null'
 
             raw_data_chunk = read_pipe.recv_bytes()
 
@@ -208,7 +207,7 @@ class RsyncEngine(engine.BackupEngine):
                     header_list = header.split('\00')
                     data_chunk = data_chunk[header_len:]
                     data_chunk = self.make_files(
-                        header_list, restore_path, read_pipe,
+                        header_list, restore_resource, read_pipe,
                         data_chunk, flushed, backup.level)
                 else:
                     LOG.info('No more data available...')
@@ -432,7 +431,7 @@ class RsyncEngine(engine.BackupEngine):
 
     @staticmethod
     def get_file_type(file_mode, fs_path):
-        """Extract file type from the the file mode retrieved
+        """Extract file type from the file mode retrieved
         from file abs path
 
         :param file_mode:
@@ -602,7 +601,7 @@ class RsyncEngine(engine.BackupEngine):
         Return the meta data as a dict structure and a binary string
 
         :param fs_path: file abs path
-        :param new_level
+        :param new_level:
         :return: file data structure
         """
 
@@ -742,7 +741,7 @@ class RsyncEngine(engine.BackupEngine):
         """Compute the file or fs tree path signatures.
 
         :param fs_path:
-        :param manifest_path
+        :param manifest_path:
         :param write_queue:
         :return:
         """
