@@ -20,6 +20,7 @@ from cinderclient import client as cinder_client
 from glanceclient import client as glance_client
 from keystoneauth1 import loading
 from keystoneauth1 import session
+from neutronclient.v2_0 import client as neutron_client
 from novaclient import client as nova_client
 from oslo_config import cfg
 from oslo_log import log
@@ -38,6 +39,7 @@ class OSClientManager(object):
         self.glance = None
         self.nova = None
         self.cinder = None
+        self.neutron = None
         self.dry_run = kwargs.pop('dry_run', None)
         loader = loading.get_plugin_loader(auth_method)
         # copy the args for swift authentication !
@@ -69,6 +71,7 @@ class OSClientManager(object):
         self.compute_version = kwargs.pop('compute_api_version', 2)
         self.image_version = kwargs.pop('image_api_version', 2)
         self.volume_version = kwargs.pop('volume_api_version', 2)
+        self.neutron_version = kwargs.pop('neutron_api_version', 2)
         self.auth = loader.load_from_options(auth_url=auth_url, **kwargs)
 
         self.sess = session.Session(auth=self.auth, **session_kwargs)
@@ -82,6 +85,15 @@ class OSClientManager(object):
                                        **self.client_kwargs)
         return self.nova
 
+    def create_neutron(self):
+        """
+        Use pre-initialized session to create an instance of neutron client.
+        :return: neutronclient instance
+        """
+        self.neutron = neutron_client.Client(session=self.sess,
+                                             **self.client_kwargs)
+        return self.neutron
+
     def create_glance(self):
         """
         Use pre-initialized session to create an instance of glance client.
@@ -165,6 +177,15 @@ class OSClientManager(object):
             self.nova = self.create_nova()
         return self.nova
 
+    def get_neutron(self):
+        """
+        Get neutronclient instance
+        :return: neutronclient instance
+        """
+        if not self.neutron:
+            self.neutron = self.create_neutron()
+        return self.neutron
+
     def get_glance(self):
         """
         Get glanceclient instance
@@ -211,11 +232,13 @@ class OSClientManager(object):
                 LOG.debug("Snapshot status: " + snapshot.status)
                 snapshot = self.get_cinder().volume_snapshots.get(snapshot.id)
                 if snapshot.status == "error":
-                    raise Exception("snapshot has error state")
+                    raise RuntimeError("snapshot has error state")
                 time.sleep(5)
+            except RuntimeError:
+                LOG.info("Delete snapshot in error state " + snapshot.id)
+                self.get_cinder().volume_snapshots.delete(snapshot)
+                raise
             except Exception as e:
-                if str(e) == "snapshot has error state":
-                    raise
                 LOG.exception(e)
         return snapshot
 
@@ -233,7 +256,13 @@ class OSClientManager(object):
             try:
                 LOG.info("Volume copy status: " + volume.status)
                 volume = self.get_cinder().volumes.get(volume.id)
+                if volume.status == "error":
+                    raise RuntimeError("Volume copy has error state")
                 time.sleep(5)
+            except RuntimeError:
+                LOG.info("Delete volume in error state " + volume.id)
+                self.get_cinder().volumes.delete(volume.id)
+                raise
             except Exception as e:
                 LOG.exception(e)
                 LOG.warning("Exception getting volume status")
@@ -259,9 +288,15 @@ class OSClientManager(object):
                 LOG.info("Image status: " + image.status)
                 image = self.get_glance().images.get(image.id)
                 if image.status in ("killed", "deleted"):
-                    raise Exception("Image have killed state")
+                    raise RuntimeError("Image in killed or deleted state")
+            except RuntimeError:
+                if image.status == 'killed':
+                    LOG.info("Delete image in killed state " + image_id)
+                    self.get_glance().images.delete(image_id)
+                raise
             except Exception as e:
-                if image.status in ("killed", "deleted"):
+                if hasattr(e, 'code') and e.code == 404:
+                    LOG.warning('Image is not found ' + image_id)
                     raise
                 LOG.exception(e)
                 LOG.warning("Exception getting image status")
@@ -398,10 +433,10 @@ class OpenstackOpts(object):
                                 'Generated from auth_url: {1}'
                                 .format(version, auth_url))
 
-                LOG.info('Authenticating with Keystone version: '
-                         '{0}, auth_url: {1}, username: {2}, project: {3}'.
-                         format(self.auth_version, self.auth_url,
-                                self.username, self.project_name))
+        LOG.info('Authenticating with Keystone version: '
+                 '{0}, auth_url: {1}, username: {2}, project: {3}'.
+                 format(self.auth_version, self.auth_url,
+                        self.username, self.project_name))
 
     def get_opts_dicts(self):
         """
